# Chaton

Chaton is a small chatbot with the following characteristics:

* [RiveScript](https://www.rivescript.com)-like Syntax
* Event-based Dialog Management for Multi-Modal Event Processing
* Context Information Exchange Protocol

## Required Software
### Python 3.x
Chaton depends on python 3.x.

### Lark
Lark is used to implement the chaton parser. Lark is a modern parser library for python hosted at [http://github.com/lark-parser](http://github.com/lark-parser). Lark can be installed by:

  ```
  pip install lark-parser
  ```

## Installation
Chaton is registered to Python Package Index, and can be installed by:

  ```
  pip install chaton
  ```

## Message Protocol

## License
Chaton uses the [GPL v3.0](https://www.gnu.org/licenses/gpl-3.0.en.html).

## Contact
Any questions or assistance? Please contact me at minsu(at)etri.re.kr.